# Easy My Coop Easy Migration

This project aim to facilitate the migration from other ERP to Odoo with EMC application:

> - Add new field to SubscriptionRequest to save the migrated cooperator number.
> - Add a wizard to validate all the SubscriptionRequests in background.
> - Add a wizard to mark as paid all the capital release invoices in background sorted by the migrated cooperator number.

Please don’t hesitate to suggest one of your modules to this project.

Table of contents

- Installation
- Usage
- Bug Tracker
- Credits
  - Authors
  - Contributors
  - Maintainers

# Installation

## Deploying with pip

We used [odoo setup tools](https://pypi.org/project/setuptools-odoo/#packaging-a-single-addon) to generate the pypi files from the odoo manifests. To deploy any packaged module, so that odoo can later install them, you can create a venv with this name (it’s git-ignored) ``shell python -m venv venv `` And then pip-install them [from pypi](https://pypi.org/user/coopdevs/).

### Example

For instance, for the addon easy_my_coop_easy_migration ``shell pip install odoo12-addon-easy-my-coop-easy-migration==12.0.1.0.0 `` Beware that for word separation, pypi uses dashes - and odoo underscores _.

# Usage

Configuration steps:

1. Configure the property_cooperator_account in Settings > Company.
2. Create the Share product and generate the ExternalId. You can export the share product to generate the external Id.
3. Add Migration Manager group to the migration user.
4. Modify the Subscription Journal sequence implementation to NoGap: Settings > Technical > Sequences > Account Default Subscription Journal

Execution steps:

1. Import SR with the migrated_cooperator_register_number and share_type/external_id.
2. Open the SR validator wizard and check the flag Force validate all in draft and validate to validate the SR and generate the partner and the capital release invoice.
3. Open the ‘Pay capital release invoice of migration’ wizard and configure the journal to use. Then execute the wizard thar enqueue a job to mask as paid all the capital release invoices.

# Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us smashing it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

# Credits

## Authors

- Coopdevs Treball SCCL

## Contributors

- Coopdevs Treball SCCL

## Maintainers

This module is maintained by the OCA.

OCA, or the Odoo Community Association, is a nonprofit organization whose mission is to support the collaborative development of Odoo features and promote its widespread use.

This module is part of the OCA/vertical-cooperative project on GitHub.

You are welcome to contribute. To learn how please visit https://odoo-community.org/page/Contribute.